; ##############################################################################
; ##############################################################################
; ##############################################################################
WDR_INITIALISIERUNG:
; Watchdog aktivieren (max. Zeit)					
	ldi TEMP,(1<<WDCE)|(1<<WDE)  
	out wdtcr,TEMP       
	ldi TEMP,(1<<WDE) | (1<<WDP2)|(1<<WDP1)|(1<<WDP0) 
	out wdtcr,temp
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; MCUCSR																		
;Bit 3  WDRF: Watchdog Reset Flag This bit is set if a Watchdog Reset occurs. The bit is reset by a Power-on Reset, or bywriting a logic zero to the flag.
;Bit 2  BORF: Brown-out Reset Flag This bit is set if a Brown-out Reset occurs. The bit is reset by a Power-on Reset, or bywriting a logic zero to the flag.
;Bit 1  EXTRF: External Reset Flag This bit is set if an External Reset occurs. The bit is reset by a Power-on Reset, or bywriting a logic zero to the flag.
;Bit 0  PORF: Power-on Reset Flag This bit is set if a Power-on Reset occurs. The bit is reset only by writing a logic zero tothe flag.
NEUSTART_MIT_WDR:
	WDR
	in temp, MCUCSR
	andi temp,0b00001000
	tst temp
	breq NEUSTART_MIT_WDR_FEHLER
;-------------------------------------------------------------------------------
	; MCUCSR = NULL
	ldi temp,0
	out MCUCSR,temp
	sbi (LED_GRUEN_PORT),LED_GRUEN_PIN_NR		; GRN aus	
	sbi (LED_GELB_PORT),LED_GELB_PIN_NR			; GELB aus	
	sbi (LED_ROT_PORT),LED_ROT_PIN_NR			; ROT  aus	
	ret
;-------------------------------------------------------------------------------
NEUSTART_MIT_WDR_FEHLER:
	cbi (LED_GRUEN_PORT),LED_GRUEN_PIN_NR		; GRN an	
	cbi (LED_GELB_PORT),LED_GELB_PIN_NR			; GELB an	
	cbi (LED_ROT_PORT),LED_ROT_PIN_NR			; ROT  an	
	rjmp NEUSTART_MIT_WDR_FEHLER
; ##############################################################################
; ##############################################################################
; ##############################################################################
;																			
; MCUCR => SE SM2 SM1 SM0 ISC11 ISC10 ISC01 ISC00 							
; SM2 SM1 SM0 Sleep Mode													
;*0   0   0   Idle															
; 0   0   1   ADC Noise Reduction											
; 0   1   0   Power-down													
; 0   1   1   Power-save													
; 1   0   0   Reserved														
; 1   0   1   Reserved														
; 1   1   0   Standby(1)													
;																			
SLEEP_INITIALISIEREN:
	ldi temp,(1<<SE)|(0<<SM2)|(1<<SM1)|(0<<SM0)
	out MCUCR,temp
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
SRAM_CLEAR:
	ldi ZL, LOW (adr_DATEN)
	ldi ZH, HIGH(adr_DATEN)
	ldi temp,0
SRAM_CLEAR_w:
	ST z+,temp
	cpi ZH, HIGH(RAMEND-1)	; Vergleich?		
	brlo SRAM_CLEAR_w		; kleiner => SPRUNG	
	cpi ZL, LOW(RAMEND-1)	; Vergleich?		
	brlo SRAM_CLEAR_w		; kleiner => SPRUNG	
	breq SRAM_CLEAR_w		; gleich  => SPRUNG	
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
RS232_INITIALISIEREN:
	ldi temp,TAKT/(BAUD*16)-1  		; Baudrate 								
	out UBRRL,temp
   	ldi temp, (1<<URSEL)|(3<<UCSZ0)	; Frame-Format: 8 Bit					
    out UCSRC, temp
    cbi UCSRB, RXCIE                ; Interrupt bei Empfang	deaktivieren		
    cbi UCSRB, RXEN 				; RX deaktivieren (Empfang)      			
	sbi UCSRB, TXEN  				; TX aktivieren                 		
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; 	INPUT: temp1														
;																		
;	rcall SENDEN	; INP: TEMP1										
;																		
RS232_DATA_TEMP:
	sbis UCSRA,UDRE  		   	; Warten bis UDR frei             	
	rjmp RS232_DATA_TEMP		; Sprung							
	out UDR, temp				; senden							
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
RS232_DATA_OUT:
	ldi temp,'*'
	rcall RS232_DATA_TEMP	
	ldi temp,'*'
	rcall RS232_DATA_TEMP

	LDS temp,(adr_RDS_BLOCK_AH)
	rcall RS232_DATA_TEMP
	LDS temp,(adr_RDS_BLOCK_AL)
	rcall RS232_DATA_TEMP

	LDS temp,(adr_RDS_BLOCK_BH)
	rcall RS232_DATA_TEMP
	LDS temp,(adr_RDS_BLOCK_BL)
	rcall RS232_DATA_TEMP

	LDS temp,(adr_RDS_BLOCK_CH)
	rcall RS232_DATA_TEMP
	LDS temp,(adr_RDS_BLOCK_CL)
	rcall RS232_DATA_TEMP

	LDS temp,(adr_RDS_BLOCK_DH)
	rcall RS232_DATA_TEMP
	LDS temp,(adr_RDS_BLOCK_DL)
	rcall RS232_DATA_TEMP

	LDS temp,(adr_RDS_ERROR)
	rcall RS232_DATA_TEMP
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
PROGRAMM_CHECK:
	; NULL		
	tst NULL
	brne PROGRAMM_CHECK_FEHLER
	; EINS		
	mov temp,EINS
	cpi temp,1
	brne PROGRAMM_CHECK_FEHLER
	; VOLL		
	mov temp,VOLL
	cpi temp,255
	brne PROGRAMM_CHECK_FEHLER
	; SRAM CHECK
	LDS temp,(adr_SRAM_CHECK)
	cpi temp,'S'
	brne PROGRAMM_CHECK_FEHLER
	ret
;-------------------------------------------------------------------------------
; SCHLEIFE																		
PROGRAMM_CHECK_FEHLER:
	rcall wait_100ms
	sbi (LED_GRUEN_PORT),LED_GRUEN_PIN_NR		; GRN aus	
	sbi (LED_GELB_PORT),LED_GELB_PIN_NR			; GELB aus	
	sbi (LED_ROT_PORT),LED_ROT_PIN_NR			; ROT  aus	
	rcall wait_100ms
	cbi (LED_GRUEN_PORT),LED_GRUEN_PIN_NR		; GRN an	
	cbi (LED_GELB_PORT),LED_GELB_PIN_NR			; GELB an	
	cbi (LED_ROT_PORT),LED_ROT_PIN_NR			; ROT  an	
	rjmp PROGRAMM_CHECK_FEHLER
; ##############################################################################
; ##############################################################################
; ##############################################################################
LED_INITIALISIERUNG:
	; auf AUSGANG								
	sbi (LED_GRUEN_DDR),(LED_GRUEN_PIN_NR)		; GRN		
	sbi (LED_GELB_DDR),(LED_GELB_PIN_NR)		; GELB		
	sbi (LED_ROT_DDR),(LED_ROT_PIN_NR)			; ROT		

	cbi (LED_GRUEN_PORT),LED_GRUEN_PIN_NR		; GRN an	
	cbi (LED_GELB_PORT),LED_GELB_PIN_NR			; GELB an	
	cbi (LED_ROT_PORT),LED_ROT_PIN_NR			; ROT  an	

	rcall wait_100ms
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
PWM_INITIALISIERUNG:
	sbi (PWM_DDR),(PWM_PIN_NR)		; auf AUSGANG
	sbi (PWM_PORT),PWM_PIN_NR		


; Timer1 Control Register-A (TCCR1A)						
	ldi  TEMP,(1<<COM1A1)|(0<<COM1A0)|(1<<COM1B1)|(0<<COM1B0)|(0<<FOC1A)|(0<<FOC1B)|(1<<WGM11)|(0<<WGM10)
	out  TCCR1A,TEMP
; Timer1 Control Register-B (TCCR1B)	 					
	ldi     TEMP,(0<<ICNC1)|(0<<ICES1)|(1<<WGM13)|(0<<WGM12)|(0<<CS12)|(0<<CS11)|(1<<CS10)
 	out     TCCR1B,TEMP
; Input Capture Register 1 (ICR1) Maximalwert Zhler		
	ldi temp,HIGH(100)
	OUT ICR1H,temp
	ldi temp,LOW (100)
	OUT ICR1L,temp
; Output Compare Register 1A (OCR1A) PWM-WERT				
	ldi temp,HIGH(100)
	OUT OCR1AH,temp
	ldi temp,LOW (100)
	OUT OCR1AL,temp

ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
ANZEIGE_PWM_ANALOGINSTRUMENT:
	LDS temp,(adr_RSSI)
	OUT OCR1AL,temp
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
ERROR_SPEICHERN_TEMP:
	; den 1. Fehler speichern		
	push temp	; sichern
	LDS temp,(adr_ERROR_CODE)
	tst temp
	breq ERROR_SPEICHERN_TEMP_RUN
	pop temp	; wieder herstellen
	ret
ERROR_SPEICHERN_TEMP_RUN:
	cbi (LED_ROT_PORT),LED_ROT_PIN_NR			; ROT  an	
	STS(adr_ERROR_CODE),temp
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
FUNKTION_TEMP1_4_MAL_10:
	mov temp5,temp1
	mov temp6,temp2
	mov temp7,temp3
	mov temp8,temp4
	; 9 mal addieren	
	ldi temp,9
FUNKTION_TEMP1_4_MAL_10_s:
	add temp1,temp5
	adc temp2,temp6
	adc temp3,temp7
	adc temp4,temp8
	dec temp
	brne FUNKTION_TEMP1_4_MAL_10_s
ret
;###############################################################################
;###############################################################################
;###############################################################################
FUNKTION_EINGABE_ZAHL_NACH_TEMP1_4:
	LDS temp1,(adr_EINGABE_ZAHL_BYTE0)
	LDS temp2,(adr_EINGABE_ZAHL_BYTE1)
	LDS temp3,(adr_EINGABE_ZAHL_BYTE2)
	LDS temp4,(adr_EINGABE_ZAHL_BYTE3)
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
